svn commit: r209751 - in head/usr.sbin/pc-sysinstall: backend-query doc pc-sysinstall

Warner Losh imp at FreeBSD.org
Tue Jul 6 23:29:56 UTC 2010


Author: imp
Date: Tue Jul  6 23:29:55 2010
New Revision: 209751
URL: http://svn.freebsd.org/changeset/base/209751

Log:
  A few patches from Ed Maste by way of Kris Moore
  
  1. Change detect-vmware to detect-emulation
  2. improve laptop detection
  3. better, network descriptions

Modified:
  head/usr.sbin/pc-sysinstall/backend-query/Makefile
  head/usr.sbin/pc-sysinstall/backend-query/detect-laptop.sh
  head/usr.sbin/pc-sysinstall/backend-query/detect-nics.sh
  head/usr.sbin/pc-sysinstall/doc/help-index
  head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.8
  head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.sh

Modified: head/usr.sbin/pc-sysinstall/backend-query/Makefile
==============================================================================
--- head/usr.sbin/pc-sysinstall/backend-query/Makefile	Tue Jul  6 23:20:43 2010	(r209750)
+++ head/usr.sbin/pc-sysinstall/backend-query/Makefile	Tue Jul  6 23:29:55 2010	(r209751)
@@ -1,6 +1,6 @@
 # $FreeBSD$
 
-FILES=	detect-laptop.sh detect-nics.sh detect-vmware.sh disk-info.sh \
+FILES=	detect-laptop.sh detect-nics.sh detect-emulation.sh disk-info.sh \
 	disk-list.sh disk-part.sh enable-net.sh list-config.sh list-components.sh \
 	list-mirrors.sh list-rsync-backups.sh list-tzones.sh query-langs.sh \
 	send-logs.sh setup-ssh-keys.sh sys-mem.sh test-live.sh test-netup.sh \

Modified: head/usr.sbin/pc-sysinstall/backend-query/detect-laptop.sh
==============================================================================
--- head/usr.sbin/pc-sysinstall/backend-query/detect-laptop.sh	Tue Jul  6 23:20:43 2010	(r209750)
+++ head/usr.sbin/pc-sysinstall/backend-query/detect-laptop.sh	Tue Jul  6 23:29:55 2010	(r209751)
@@ -25,9 +25,8 @@
 #
 # $FreeBSD$
 
-dmesgLine=`dmesg | grep "acpi_acad0"`
-if test "${dmesgLine}" = ""; then
-  echo "laptop: NO"
-else
+if devinfo | grep 'acpi_acad0' >/dev/null 2>/dev/null; then
   echo "laptop: YES"
-fi 
+else
+  echo "laptop: NO"
+fi

Modified: head/usr.sbin/pc-sysinstall/backend-query/detect-nics.sh
==============================================================================
--- head/usr.sbin/pc-sysinstall/backend-query/detect-nics.sh	Tue Jul  6 23:20:43 2010	(r209750)
+++ head/usr.sbin/pc-sysinstall/backend-query/detect-nics.sh	Tue Jul  6 23:29:55 2010	(r209751)
@@ -25,17 +25,12 @@
 #
 # $FreeBSD$
 
-rm /tmp/netCards 2>/dev/null
-touch /tmp/netCards
-
-config="`ifconfig -l`"
-
-for i in $config
-do
- echo "${i}" | grep -e "lo0" -e "^fwe" -e "^fwip" -e "lo1" -e "^plip" -e "^pfsync" -e "^pflog" -e "^tun" >/dev/null 2>/dev/null
- if [ "$?" != "0" ]
- then
-   IDENT="<`dmesg | grep ^${i} | grep -v "miibus" | grep '<' | cut -d '<' -f 2 | cut -d '>' -f 1 | head -1`>"
-   echo "${i}: $IDENT"
- fi
+for i in $(ifconfig -l); do
+  case "${i%%[0-9]*}" in
+  lo|fwe|fwip|plip|pfsync|pflog|tun)
+    continue
+    ;;
+  esac
+  IDENT=$(dmesg | sed -n "s/^$i: <\(.*\)>.*$/\1/p" | head -1)
+  echo "${i}: <$IDENT>"
 done

Modified: head/usr.sbin/pc-sysinstall/doc/help-index
==============================================================================
--- head/usr.sbin/pc-sysinstall/doc/help-index	Tue Jul  6 23:20:43 2010	(r209750)
+++ head/usr.sbin/pc-sysinstall/doc/help-index	Tue Jul  6 23:29:55 2010	(r209751)
@@ -22,8 +22,8 @@ System Query Commands
     detect-laptop
 	Tests to see if this system is a laptop or desktop
 
-    detect-vmware
-	Tests to see if this system is actually a vmware session
+    detect-emulation
+	Tests to see if this system is actually running in an emulator such as VirtualBox
     
     detect-nics
 	Returns a listing of the detected network cards on this system

Modified: head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.8
==============================================================================
--- head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.8	Tue Jul  6 23:20:43 2010	(r209750)
+++ head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.8	Tue Jul  6 23:29:55 2010	(r209751)
@@ -69,8 +69,8 @@ Returns information about a storage devi
 sectors.
 .It detect-laptop
 Tests to see if this system is a laptop or desktop.
-.It detect-vmware
-Tests to see if this system is a vmware session.
+.It detect-emulation
+Tests to see if this system is running in an emulator
 .It detect-nics
 Returns a listing of the detected network cards on this system.
 .It list-components

Modified: head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.sh
==============================================================================
--- head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.sh	Tue Jul  6 23:20:43 2010	(r209750)
+++ head/usr.sbin/pc-sysinstall/pc-sysinstall/pc-sysinstall.sh	Tue Jul  6 23:29:55 2010	(r209751)
@@ -124,8 +124,8 @@ case $1 in
   detect-nics) ${QUERYDIR}/detect-nics.sh
   ;;
   
-  # The user is wanting to check if we are in vmware
-  detect-vmware) ${QUERYDIR}/detect-vmware.sh
+  # The user is wanting to check if we are in emulation
+  detect-emulation) ${QUERYDIR}/detect-emulation.sh
   ;;
 
   # The user is wanting to query a disk's information


More information about the svn-src-all mailing list